#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 invariant
version:              0.5.4
visibility:           public
id:                   invariant-0.5.4-ChKFWwHOaxKFtZqQoiONbL
key:                  invariant-0.5.4-ChKFWwHOaxKFtZqQoiONbL
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  cbd73708542b5dd1b22f1d8892e10609
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-8.10.5/site-local/invariant-0.5.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/invariant-0.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/invariant-0.5.4
hs-libraries:         HSinvariant-0.5.4-ChKFWwHOaxKFtZqQoiONbL
depends:
    StateVar-1.2.1-45lyVllRWLO2FnRWpLVlP1 array-0.5.4.0 base-4.14.2.0
    bifunctors-5.5.11-5WHPU2oStxP1cNabXCzf9E
    comonad-5.0.8-3VlYiILWTa24txTyM8uxMS containers-0.6.4.1
    contravariant-1.5.3-KWoYE9wiUjmElzHNq2wj10 ghc-prim-0.6.1
    profunctors-5.6.2-68Okl6PP0cYKcJgfa1by0Q stm-2.5.0.1
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-5X2XqBZ7rCLBwJXut5dQBZ transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

